guix-devel
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[PATCH] Work around behavior of old 'scandir' in Guile 2.0.5


From: Mark H Weaver
Subject: [PATCH] Work around behavior of old 'scandir' in Guile 2.0.5
Date: Sun, 06 Apr 2014 19:55:59 -0400

This patch is needed when Guix is built with Guile 2.0.5.

    Mark

>From a49c33418aa6814daf6fcab5978c27afbfe8ac9a Mon Sep 17 00:00:00 2001
From: Mark H Weaver <address@hidden>
Date: Sun, 6 Apr 2014 19:46:16 -0400
Subject: [PATCH] Work around behavior of old 'scandir' in Guile 2.0.5.

Problem reported by John Darrington <address@hidden>.

* guix/nar.scm (write-file): Filter out "." and ".." from the result of
  'scandir'.  Previously we did this by passing a suitable predicate.
---
 guix/nar.scm | 20 +++++++++++++-------
 1 file changed, 13 insertions(+), 7 deletions(-)

diff --git a/guix/nar.scm b/guix/nar.scm
index b642143..5b602df 100644
--- a/guix/nar.scm
+++ b/guix/nar.scm
@@ -1,5 +1,6 @@
 ;;; GNU Guix --- Functional package management for GNU
 ;;; Copyright © 2012, 2013, 2014 Ludovic Courtès <address@hidden>
+;;; Copyright © 2014 Mark H Weaver <address@hidden>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -177,13 +178,18 @@ sub-directories of FILE as needed."
         ((directory)
          (write-string "type" p)
          (write-string "directory" p)
-         (let* ((select? (negate (cut member <> '("." ".."))))
-
-                ;; 'scandir' defaults to 'string-locale<?' to sort files, but
-                ;; this happens to be case-insensitive (at least in 'en_US'
-                ;; locale on libc 2.18.)  Conversely, we want files to be
-                ;; sorted in a case-sensitive fashion.
-                (entries (scandir f select? string<?)))
+         (let ((entries
+                ;; NOTE: Guile 2.0.5's 'scandir' returns all subdirectories
+                ;; unconditionally, including "." and "..", regardless of the
+                ;; 'select?' predicate passed to it, so we have to filter
+                ;; those out externally.
+                (filter (negate (cut member <> '("." "..")))
+                        ;; 'scandir' defaults to 'string-locale<?' to sort
+                        ;; files, but this happens to be case-insensitive (at
+                        ;; least in 'en_US' locale on libc 2.18.)  Conversely,
+                        ;; we want files to be sorted in a case-sensitive
+                        ;; fashion.
+                        (scandir f (const #t) string<?))))
            (for-each (lambda (e)
                        (let ((f (string-append f "/" e)))
                          (write-string "entry" p)
-- 
1.8.4


reply via email to

[Prev in Thread] Current Thread [Next in Thread]